Module: sems
Branch: master
Commit: e02a94354ab7009fed032900e54364268f79a442
URL:    
http://git.sip-router.org/cgi-bin/gitweb.cgi/sems/?a=commit;h=e02a94354ab7009fed032900e54364268f79a442

Author: Raphael Coeffic <[email protected]>
Committer: Raphael Coeffic <[email protected]>
Date:   Mon May  9 12:02:44 2011 +0200

b/f: pass only 200-ACK request to the UA layer.

---

 core/sip/trans_layer.cpp |   19 ++++++++++++-------
 1 files changed, 12 insertions(+), 7 deletions(-)

diff --git a/core/sip/trans_layer.cpp b/core/sip/trans_layer.cpp
index fd70adf..9e46ddd 100644
--- a/core/sip/trans_layer.cpp
+++ b/core/sip/trans_layer.cpp
@@ -1125,13 +1125,18 @@ void _trans_layer::received_msg(sip_msg* msg)
                    // should we forward the ACK to SEMS-App upstream? Yes
                    bucket->unlock();
                    
-                   //  let's pass the request to
-                   //  the UA. 
-                   assert(ua);
-                   DBG("Passing ACK to the UA.\n");
-                   ua->handle_sip_request(trans_ticket(), // dummy
-                                          msg);
-                   
+                   if(err == TS_REMOVED) {
+                       //  let's pass the request to
+                       //  the UA, iff it was a 200-ACK
+                       assert(ua);
+                       DBG("Passing ACK to the UA.\n");
+                       ua->handle_sip_request(trans_ticket(), // dummy
+                                              msg);
+                   }
+                   else {
+                       DBG("Absorbing non-200-ACK\n");
+                   }
+
                    DROP_MSG;
                }
            }

_______________________________________________
Semsdev mailing list
[email protected]
http://lists.iptel.org/mailman/listinfo/semsdev

Reply via email to